@@ -11,7 +11,7 @@ use super::{
     Client,
 };
 use crate::client::Error;
-use crate::messaging::client::{ChunkRead, ChunkWrite, DataCmd, DataQuery, Query, QueryResponse};
+use crate::messaging::client::{ChunkRead, ChunkWrite, DataCmd, DataQuery, QueryResponse};
 use crate::types::{Chunk, ChunkAddress, PrivateChunk, PublicChunk, PublicKey};
 use bincode::{deserialize, serialize};
 use self_encryption::{DataMap, SelfEncryptor};
@@ -121,7 +121,7 @@ impl Client {
         }
 
         let res = self
-            .send_query(Query::Data(DataQuery::Blob(ChunkRead::Get(head_address))))
+            .send_query(DataQuery::Blob(ChunkRead::Get(head_address)))
             .await?;
 
         let msg_id = res.msg_id;
