@@ -9,26 +9,27 @@
 use std::result;
 use thiserror::Error;
 
-/// A specialised `Result` type for safecoin.
+/// A specialised `Result` type for messaging APIs.
 pub type Result<T, E = Error> = result::Result<T, E>;
 
+/// Errors that can occur when interacting with messaging APIs.
 #[derive(Error, Debug)]
 #[non_exhaustive]
-/// Error messages across the network
 pub enum Error {
-    /// Error message sent from a client
-    #[error("Error received from a client")]
-    Client(String),
-    /// Serialisation error
+    /// An error occurred when serializing a message.
+    // In reality, serialisation itself should be infallible, so this should only occur when
+    // serialising involves I/O (e.g. serialising to `io::Write`). As such, we might want to replace
+    // this with an `io::Error` variant, if it's ever applicable.
     #[error("Failed to serialize message: {0}")]
     Serialisation(String),
-    /// Failed to parse a string.
+
+    /// Failed to parse a message.
+    ///
+    /// The `String` will be a human-readable indication of the problem with the message.
     #[error("Failed to parse: {0}")]
     FailedToParse(String),
+
     /// Message read was built with an unsupported version.
     #[error("Unsupported messaging protocol version: {0}")]
     UnsupportedVersion(u16),
-    /// Message is of an unsupported kind.
-    #[error("Unsupported messaging kind: {0}")]
-    UnsupportedMessageKind(u8),
 }
